/*
*/
/**
@file IO.c
@brief Chip specific stuff


\author    Chipc
\version   1.0
\date      Apr 7, 2019
*/


/*#################################Includes##################################*/
#include "IO.h"
#include "InitDevice.h"

/*#############################Private Definitions###########################*/

#define SINE_PHASE_0 127
#define SINE_PHASE_1 177
#define SINE_PHASE_2 219
#define SINE_PHASE_3 246
#define SINE_PHASE_4 255
#define SINE_PHASE_5 79
#define SINE_PHASE_6 37
#define SINE_PHASE_7 10
#define SINE_PHASE_8 0

/*###############################Private Data################################*/


/*###############################Public Data#################################*/




/*##############################Private Functions############################*/




/*###############################Public Functions############################*/

/******************************************************************************/
/*
@brief
Waits so many microseconds

Multiplies by five for use with a 200ns PCA clock.

@param x How many microseconds to wait

@exception x must be less than 13000 or 13ms
******************************************************************************/
void IOWaitUs(unsigned int x) reentrant
{

	UU16 capture, start;

	x=(x*5);/*Multiply by 5*/

	/*Seed the first reading, LB first*/
	start.U8[LSB]=PCA0L;
	start.U8[MSB]=PCA0H;


	/*Save the starting point*/
	capture.U16=start.U16;

	/*Cycle around until time out*/
	while((capture.U16-start.U16)<x)
	{
		capture.U8[LSB]=PCA0L;
		capture.U8[MSB]=PCA0H;
	}
}


/******************************************************************************/
/*
@brief
Waits so many milliseconds

Calls IOWaitUs over and over again

@param x How many milliseconds to wait


******************************************************************************/
void IOWait(unsigned int x)
{
	for(;x>0;x--)
	{
		IOWaitUs(1000);
	}
}


/******************************************************************************/
/**
@brief
Generates the sine wave

There is a table of nine values for the sine wave.  This will be used to drive
the transformer through sixteen different states.


******************************************************************************/
SI_INTERRUPT (SINE_ISR, TIMER2_IRQn)
{
	static U8 sinePhase=0;

	TMR2CN0_TF2H=0;

	switch (sinePhase)
	{
		default:
		PCA0CPH0=SINE_PHASE_0;
		sinePhase=0;
		break;

		case 1:
		PCA0CPH0=SINE_PHASE_1;
		break;

		case 2:
		PCA0CPH0=SINE_PHASE_2;
		break;

		case 3:
		PCA0CPH0=SINE_PHASE_3;
		break;

		case 4:
		PCA0CPH0=SINE_PHASE_4;
		break;

		case 5:
		PCA0CPH0=SINE_PHASE_3;
		break;

		case 6:
		PCA0CPH0=SINE_PHASE_2;
		break;

		case 7:
		PCA0CPH0=SINE_PHASE_1;
		break;

		case 8:
		/*Phase just switched*/
		PCA0CPH0=SINE_PHASE_0;
		break;

		case 9:
		PCA0CPH0=SINE_PHASE_5;
		break;

		case 10:
		PCA0CPH0=SINE_PHASE_6;
		break;

		case 11:
		PCA0CPH0=SINE_PHASE_7;
		break;

		case 12:
		PCA0CPH0=SINE_PHASE_8;
		break;

		case 13:
		PCA0CPH0=SINE_PHASE_7;
		break;

		case 14:
		PCA0CPH0=SINE_PHASE_6;
		break;

		case 15:
		PCA0CPH0=SINE_PHASE_5;
		break;

	}
	sinePhase++;
}



/******************************************************************************/
/*
@brief
Turns the LCD On or Off

If the LCD is to be off, all ones are written to the port

@param /b TRUE to turn LCD on

******************************************************************************/
void IOLCDOn(bit x)
{
	if(!x)
	{
		LCDPort=0xFF;
	}

	IOLCDPower=!x;
}
