/*
*/
/**
@file IO.h
@brief All the chip specific definitions and macros

Lengthy description

\author    ChipC
\version   1.0
\date      July 26, 2017
*/


#ifndef IO_H_
#define IO_H_



/*#################################Includes##################################*/
#include <SI_EFM8SB2_Register_Enums.h>                  // SFR declarations
#include <compiler_defs.h>



/*##############################Public Definitions###########################*/


sbit PB0=P2^2;
sbit PB1=P2^3;
sbit BACKLIGHT=P1^5;

sbit IOlcdA=P1^0;
sbit IOlcdWrite=P1^1;
sbit IOlcdRead=P1^2;
sbit IOLCDPower=P1^7;

#define DI() IE_EA = 0
#define EI() IE_EA = 1

#define LCDPort P0
#define IOlcdA0(x) IOlcdA=x
#define IOlcdWrite(x) IOlcdWrite=!x
#define IOlcdRead(x) IOlcdRead=!x
#define IOlcd(y) LCDPort=y
#define IOBacklight(x) BACKLIGHT=x;

/*##############################Public Data##################################*/





/*###############################Public Functions############################*/


/******************************************************************************/
/**
@brief
Waits so many microseconds

Multiplies by five for use with a 200ns PCA clock.

@param x How many microseconds to wait

@exception x must be less than 13000 or 13ms
******************************************************************************/
void IOWaitUs(unsigned int x) reentrant;

/******************************************************************************/
/**
@brief
Waits so many milliseconds

Calls IOWaitUs over and over again

@param x How many milliseconds to wait


******************************************************************************/
void IOWait(unsigned int x);

/******************************************************************************/
/**
@brief
Turns the LCD On or Off

If the LCD is to be off, all ones are written to the port

@param /b TRUE to turn LCD on

******************************************************************************/
void IOLCDOn(bit x);




#endif /* IO_H_ */







