/*
*/
/**
@file Keyboard.c
@brief Slightly modified keyboard module

\author    chipc
\version   1.0
\date      Jun 8, 2018
*/


/*#################################Includes##################################*/
#include "IO.h"
#include "Keyboard.h"

/*#############################Private Definitions###########################*/

#define INIT_SLOW_SLEW 4/**<Number of slow slews to pass before fast slew*/

#define MAIN_LOOP_FREQ (30)

#define FIRST_PRESS (MAIN_LOOP_FREQ/8)/**<Debounce for first press*/

#define	SLOW_SLEW (MAIN_LOOP_FREQ/2)/**<Debounce rate for slewing slowly*/

#define FAST_SLEW (MAIN_LOOP_FREQ/8)/**<Debounce rate for slewing quickly*/



/*###############################Private Data################################*/
U8 goodKey;



/*###############################Public Data#################################*/



/*##############################Private Functions############################*/



/*###############################Public Functions############################*/


void KeyboardDebounce(void)
{
	/* locals */
	static unsigned char lastKey;
	static unsigned char keyDbnc=FIRST_PRESS;
	static unsigned char slowSlew=INIT_SLOW_SLEW;
	static bit keybdEnable=0;
	U8 currentKey;

	/* Initialize working variables */
	goodKey=0;

	/* Grab the keys */
	currentKey=P2;
	currentKey=(~currentKey) & KEYBOARD_MASK;

	/* if the current key = last key */
	if (currentKey==lastKey)
	{
		/* decrement the debounce counter */
		keyDbnc--;
	}
	/* else */
	else
	{
		/* restart debounce */
		lastKey=currentKey;
		keyDbnc=FIRST_PRESS;
		slowSlew=INIT_SLOW_SLEW;
	}

	/* if fully debounced */
	if (keyDbnc==0)
	{
		/* if an all up event */
		if (currentKey==0)
		{
			/* enable keyboard for all up */
			keybdEnable=1;
			lastKey=currentKey;
			keyDbnc=FIRST_PRESS;
			slowSlew=INIT_SLOW_SLEW;
		}
		/* else */
		else
		{
			/* if the keyboard is enabled */
			if (keybdEnable)
			{
				/* decrement the slow slew counter if slewing */
				//slowSlew--;

				/* if slow slew finished */
				if (slowSlew==0)
				{
					/* load the fast slew rate */
					keyDbnc=FAST_SLEW;
					slowSlew++;
				}
				/* else */
				else
				{
					/* reload the slow slew */
					keyDbnc=SLOW_SLEW;
				}

				/* we have a debounced key */
				goodKey=currentKey;
			}
		}
	}
}

U8 KeyboardGetKey(void)
{
	/* return goodKey */
	return goodKey;
}
