/*
*/
/**
@file LCD.h
@brief Newhaven Display functionality

\author    chipc
\version   1.0
\date      May 11, 2019
*/


#ifndef INC_LCD_H_
#define INC_LCD_H_



/*#################################Includes##################################*/

/*##############################Public Definitions###########################*/


#define LCD_DISPLAY_ON 0xAE
#define LCD_START_SET 0x40
#define LCD_PAGE_SET	0xB0
#define LCD_COLUMN_SET 0x10
#define LCD_STATUS_READ 0x00
#define LCD_REVERSE_SET 0xA6
#define LCD_ALL_ON 0xA4
#define LCD_WRITE_MODIFY 0xE0
#define LCD_MODIFY_END 0xEE
#define LCD_RESET 0xE2
#define LCD_DISPLAY_RUN 0xAC


/*##############################Public Data##################################*/
extern xdata U8 frameBuffer[8][128];

/*###############################Public Functions############################*/

/******************************************************************************/
/**
@brief
Writes a byte of data to the LCD

@param x byte to write


******************************************************************************/
void LCDWriteData(unsigned char x);

/******************************************************************************/
/**
@brief
Reads a byte of data from the LCD

******************************************************************************/
unsigned char LCDReadData(void);

/******************************************************************************/
/**
@brief
Writes a command to the LCD

@param x command to send

******************************************************************************/
void LCDWriteCommand(unsigned char x);

/******************************************************************************/
/**

@brief
Writes the entire frame buffer to the display

Sends whatever is currently in the buffer to the display, buffer remains intact


******************************************************************************/
void LCDWriteBuffer(void);

/******************************************************************************/
/**

@brief
Clears the frame buffer but not the display

******************************************************************************/
void LCDClearFrameBuffer(void);

/******************************************************************************/
/**

@brief
Sets the LCD column

@param x column to set

******************************************************************************/
void LCDSetColumn(unsigned char x);

/******************************************************************************/
/**
@brief
Sets the page

Sends the command to set the LCD page

@param x page to set

******************************************************************************/
void LCDSetPage(unsigned char x);

/******************************************************************************/
/**

@brief
Clears the display


******************************************************************************/
void LCDClearDisplay(void);



/******************************************************************************/
/**
@brief
Initializes the display

All the commands for starting up the LCD are here
******************************************************************************/

void LCDInit(void);



/*******************************************************************************
 *
 * @brief
 * Writes a character bitmap from ROM to the screen
 *
 * A character bitmap is a font character formatted as tiles, similar to a font
 * file.  For this LCD a bitmap is arranged as a single byte holding a column with
 * b0 at the top.  Multiple columns are multiple bytes. Characters taller than 8
 * pixels have multiple bytes with the top byte being the low byte.  Height and
 * width are constants taken from the font file.  Only one font allowed in this
 * version.
 *
 * @param x X coordinate of placement on screen
 * @param y Y coordinate of placement on screen
 * @param src Where the bitmap is located
 *
*******************************************************************************/
void LCDWriteRLE(U8 x, U8 y, U8 code *src);

#endif /* INC_LCD_H_ */



